==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/FlowsessionCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Flowsession;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.FileattachmentRequest;
import microsoft.dynamics.crm.entity.request.FlowsessionRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.entity.request.WorkflowbinaryRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class FlowsessionCollectionRequest extends CollectionPageEntityRequest<Flowsession, FlowsessionRequest>{

    protected ContextPath contextPath;

    public FlowsessionCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Flowsession.class, cp -> new FlowsessionRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest flowsession_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("flowsession_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest flowsession_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("flowsession_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest flowsession_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("flowsession_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest flowsession_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("flowsession_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest flowsession_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("flowsession_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest flowsession_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("flowsession_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest flowsession_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("flowsession_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest flowsession_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("flowsession_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest flowsession_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("flowsession_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest flowsession_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("flowsession_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest flowsession_FileAttachments() {
        return new FileattachmentCollectionRequest(contextPath.addSegment("flowsession_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest flowsession_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("flowsession_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

    public WorkflowbinaryCollectionRequest flowsession_workflowbinary_FlowSessionId() {
        return new WorkflowbinaryCollectionRequest(contextPath.addSegment("flowsession_workflowbinary_FlowSessionId"), Optional.empty());
    }

    public WorkflowbinaryRequest flowsession_workflowbinary_FlowSessionId(String workflowbinaryid) {
        return new WorkflowbinaryRequest(contextPath.addSegment("flowsession_workflowbinary_FlowSessionId").addKeys(new NameValue(workflowbinaryid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/FlowsessionCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Flowsession;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.FileattachmentRequest;
import microsoft.dynamics.crm.entity.request.FlowsessionRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.entity.request.WorkflowbinaryRequest;

public class FlowsessionCollectionRequest extends CollectionPageEntityRequest<Flowsession, FlowsessionRequest>{

    protected ContextPath contextPath;

    public FlowsessionCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Flowsession.class, cp -> new FlowsessionRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest flowsession_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("flowsession_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest flowsession_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("flowsession_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest flowsession_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("flowsession_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest flowsession_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("flowsession_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest flowsession_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("flowsession_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest flowsession_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("flowsession_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest flowsession_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("flowsession_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest flowsession_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("flowsession_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest flowsession_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("flowsession_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest flowsession_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("flowsession_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest flowsession_FileAttachments() {
        return new FileattachmentCollectionRequest(contextPath.addSegment("flowsession_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest flowsession_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("flowsession_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

    public WorkflowbinaryCollectionRequest flowsession_workflowbinary_FlowSessionId() {
        return new WorkflowbinaryCollectionRequest(contextPath.addSegment("flowsession_workflowbinary_FlowSessionId"), Optional.empty());
    }

    public WorkflowbinaryRequest flowsession_workflowbinary_FlowSessionId(String workflowbinaryid) {
        return new WorkflowbinaryRequest(contextPath.addSegment("flowsession_workflowbinary_FlowSessionId").addKeys(new NameValue(workflowbinaryid.toString())), Optional.empty());
    }

}
